==> gaby-1.0.0.tar.gz: gaby-1.0.0/src/list.c <==
/*  Gaby
 *  Copyright (C) 1998 Frederic Peters
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "gaby.h"
#include <gtk/gtk.h>
#include "list.h"
#include "form.h"
#include "main.h"
#include "menu_callbacks.h"
#include "dialogs.h"
#include "useful.h"

GtkWidget *clist;
static gint colsearch;

void fillclist()
{
	record *ent;
	gchar *newrow[3];
	gboolean dontstop=TRUE;
	gint *az=NULL;
	gint i;
	
	if ( all_records == NULL || all_records->data == NULL ) {
		gtk_clist_clear(GTK_CLIST(clist));
		return;
	}

	az = bases_vsblt(az);
	all_records = g_list_first(all_records);
	gtk_clist_freeze( GTK_CLIST(clist));

	for ( i=0;i<nb_col;i++ ) {
		gtk_clist_set_column_title( GTK_CLIST(clist), i, \
				_(labels[itl[i]]));
	}
			
	gtk_clist_clear( GTK_CLIST(clist));
	do {
		ent = all_records->data;
		if ( ent->shown == TRUE && az[ent->frombook-1] == TRUE ) {
			for ( i=0; i<nb_col;i++ ) {
				newrow[i] = ent->info[itl[i]]->str;
			}
			gtk_clist_append( GTK_CLIST (clist), newrow);
		}
		if ( all_records->next == NULL ) {
			dontstop = FALSE;
		} else {
			all_records = g_list_next(all_records);
		}
	} while ( dontstop );
	g_free(az);
	gtk_clist_thaw(GTK_CLIST(clist));

	return;
}

void sort_column(GtkCList *clist, gint column)
{
	if ( srwc ) { save_record(NULL,0); }

	base_sort(itl[column]);
	fillclist();
	show_record_inform();
}

void select_record(GtkCList *clist, gint row, gint column, \
				GdkEventButton *event, GtkWidget* butform)
{
	shown_record = row;
	show_record_inform();
	if ( ofwos == TRUE && form_window != NULL ) {
		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(butform), TRUE );
	}
}

gboolean close_list (GtkObject *object, gpointer user_data)
{
	GtkWidget *menuitem;
	
	if ( !(startup_mode & 0x01) ) {
		gtk_main_quit();
	} else {
		menuitem = gtk_object_get_data(GTK_OBJECT(list_window), \
				"menuitem" );
		gtk_widget_set_sensitive(menuitem, TRUE);
		gtk_widget_hide (list_window);
	}
	return TRUE;
}

void search_event(GtkWidget *widget, GtkWidget *search_combo)
{
	GString *st;
	st = g_string_new(gtk_entry_get_text(GTK_ENTRY(search_combo)));
	record_select(st, colsearch, 1);
	g_string_free(st, 1);
	fillclist();
	show_record_inform();
}

static void setsearch(GtkWidget *widget, gint a)
{
	colsearch = a;
}

void destroy_list (GtkWidget *widget, gpointer data)
{
	GtkWidget *menuitem;
	list_window = create_list_window();
	menuitem = gtk_object_get_data(GTK_OBJECT(list_window), "menuitem" );
	gtk_widget_set_sensitive(menuitem, TRUE);
}

void form_toggle (GtkWidget *widget, GtkWidget *butclose)
{
	if (GTK_TOGGLE_BUTTON (widget)->active)
	{
		gtk_widget_show(GTK_WIDGET(form_window));
		gtk_widget_set_sensitive(butclose, TRUE);
	} else {
		gtk_widget_hide(GTK_WIDGET(form_window));
		if ( startup_mode & 0x01 ) {
			gtk_widget_set_sensitive(butclose, FALSE);
		}
	}
}

void advsearch_click (GtkWidget *widget, GtkWidget *butadvsearch)
{
	gtk_widget_show(create_advsearch_window());
}

GtkWidget* create_list_window ()
{
	GtkWidget	*win,
			*list_vbox,
			*list_hbuttonbox,
			*searchbox,
			*searchcombo,
			*butclose, *butform, *butadvsearch,
			*hs,
			*option_menu,
			*optionmenu_menu,
			*label;
#if ( GTK_MAJOR_VERSION == 1 && \
		GTK_MINOR_VERSION == 1 && GTK_MICRO_VERSION >= 5 )
	GtkWidget	*sclwin;
#endif
	gint i;
	
	if ( list_window != NULL ) {
		return list_window;
	}
	
	win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	gtk_container_border_width (GTK_CONTAINER (win), 5);
	gtk_signal_connect (GTK_OBJECT (win), "delete_event", \
			GTK_SIGNAL_FUNC (close_list), NULL);
	gtk_signal_connect (GTK_OBJECT (win), "destroy", \
			GTK_SIGNAL_FUNC (destroy_list), NULL);
			
	gtk_window_set_title (GTK_WINDOW (win), _("Gaby [List]") );
	gtk_window_set_policy (GTK_WINDOW (win), TRUE, TRUE, FALSE);
	gtk_widget_set_usize (GTK_WIDGET(win), 400, 400);
	
	list_vbox = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (list_vbox);
	gtk_container_add (GTK_CONTAINER (win), list_vbox);

	clist = gtk_clist_new (nb_col);
	gtk_widget_show (clist);
#if ( GTK_MAJOR_VERSION == 1 && \
		GTK_MINOR_VERSION == 1 && GTK_MICRO_VERSION >= 5 )
	sclwin = gtk_scrolled_window_new (NULL, NULL);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sclwin), \
			GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
	gtk_container_add (GTK_CONTAINER (sclwin), clist);
	gtk_box_pack_start (GTK_BOX (list_vbox), sclwin, TRUE, TRUE, 0);
	gtk_widget_show(sclwin);
#else	
	gtk_clist_set_policy (GTK_CLIST (clist), GTK_POLICY_ALWAYS, \
			GTK_POLICY_AUTOMATIC);
	gtk_box_pack_start (GTK_BOX (list_vbox), clist, TRUE, TRUE, 0);
#endif	

	gtk_container_border_width (GTK_CONTAINER (clist), 4);
	for ( i=0; i< nb_col-1; i++ ) {
		gtk_clist_set_column_width (GTK_CLIST(clist),i,360/nb_col);
	}
	gtk_clist_set_column_width (GTK_CLIST (clist), i, 320-i*(360/nb_col) );
	gtk_clist_set_column_justification (GTK_CLIST(clist), nb_col-1, \
			GTK_JUSTIFY_RIGHT );
	gtk_clist_set_row_height(GTK_CLIST (clist), 20);
	gtk_clist_column_titles_show (GTK_CLIST (clist));

	for ( i=0; i<nb_col;i++ ) {
		gtk_clist_set_column_title( GTK_CLIST (clist), i , \
				_(labels[itl[i]]));
	}
	gtk_signal_connect(GTK_OBJECT (clist), "click_column", \
			GTK_SIGNAL_FUNC (sort_column), NULL );
	
	searchbox = gtk_hbox_new(FALSE,0);
	gtk_widget_show(searchbox);
	gtk_box_pack_start(GTK_BOX(list_vbox), searchbox, FALSE, TRUE, 5);

	label = gtk_label_new(_("Search for" ));
	gtk_widget_show(label);
	gtk_box_pack_start (GTK_BOX (searchbox), label, TRUE, FALSE, 5);
	
	searchcombo = gtk_entry_new_with_max_length(50);
	gtk_signal_connect(GTK_OBJECT(searchcombo), "changed", \
			GTK_SIGNAL_FUNC(search_event), searchcombo);
	gtk_widget_show(searchcombo);
	gtk_box_pack_start (GTK_BOX (searchbox), searchcombo, TRUE, FALSE, 5);
	
	label = gtk_label_new(_("in"));
	gtk_widget_show(label);
	gtk_box_pack_start (GTK_BOX (searchbox), label, TRUE, FALSE, 5);

	option_menu = gtk_option_menu_new ();
	gtk_widget_show (option_menu);
	gtk_box_pack_start (GTK_BOX (searchbox), option_menu, TRUE, FALSE, 5);
	optionmenu_menu = create_labels_menu(0, GTK_SIGNAL_FUNC(setsearch));

	gtk_option_menu_set_menu(GTK_OPTION_MENU(option_menu), optionmenu_menu);
	
	hs = gtk_hseparator_new ();
	gtk_widget_show (hs);
	gtk_box_pack_start (GTK_BOX (list_vbox), hs, FALSE, TRUE, 0);
			
	list_hbuttonbox = gtk_hbutton_box_new ();
	gtk_button_box_set_layout (GTK_BUTTON_BOX (list_hbuttonbox), \
			GTK_BUTTONBOX_SPREAD);
	gtk_widget_show (list_hbuttonbox);
	gtk_box_pack_start (GTK_BOX (list_vbox), list_hbuttonbox, \
							FALSE, TRUE, 0);
	gtk_container_border_width (GTK_CONTAINER (list_hbuttonbox), 5);
	
	if ( !(startup_mode & 0x01 )  ) {
		butclose = gtk_button_new_with_label (_("Exit"));
	} else {
		butclose = gtk_button_new_with_label (_("Close"));
	}
	gtk_widget_show (butclose);

	butform = gtk_toggle_button_new_with_label(_("Form window"));
	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(butform), \
			startup_mode & 0x01 );
	gtk_signal_connect (GTK_OBJECT (butform), "toggled", \
			GTK_SIGNAL_FUNC (form_toggle), butclose);
	gtk_widget_show(butform);
	gtk_container_add (GTK_CONTAINER (list_hbuttonbox), butform);
	
	butadvsearch = gtk_button_new_with_label(_("Advanced search"));
	gtk_signal_connect (GTK_OBJECT (butadvsearch), "clicked", \
			GTK_SIGNAL_FUNC (advsearch_click), butadvsearch);
	gtk_widget_set_sensitive(butadvsearch, FALSE);
/*	gtk_widget_show(butadvsearch);*/
	gtk_container_add (GTK_CONTAINER (list_hbuttonbox), butadvsearch);
	
	gtk_signal_connect (GTK_OBJECT (butclose), "clicked", \
			GTK_SIGNAL_FUNC (close_list), NULL);
	
	gtk_signal_connect(GTK_OBJECT(clist), "select_row", \
			GTK_SIGNAL_FUNC(select_record), butform);
	gtk_container_add (GTK_CONTAINER (list_hbuttonbox), butclose);

	fillclist();
	
	return win;
}

==> gaby-1.0.6.tar.gz: gaby-1.0.6/src/list.c <==
/*  Gaby
 *  Copyright (C) 1998 Frederic Peters
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "gaby.h"
#include <gtk/gtk.h>
#include "list.h"
#include "form.h"
#include "main.h"
#include "menu_callbacks.h"
#include "dialogs.h"
#include "useful.h"

GtkWidget *clist;
static gint colsearch;

void fillclist()
{
	record *ent;
	gchar *newrow[3];
	gboolean dontstop=TRUE;
	gint *az=NULL;
	gint i;
	
	if ( all_records == NULL || all_records->data == NULL ) {
		gtk_clist_clear(GTK_CLIST(clist));
		return;
	}

	az = bases_vsblt(az);
	all_records = g_list_first(all_records);
	gtk_clist_freeze( GTK_CLIST(clist));

	for ( i=0;i<nb_col;i++ ) {
		gtk_clist_set_column_title( GTK_CLIST(clist), i, \
				_(labels[itl[i]]));
	}
			
	gtk_clist_clear( GTK_CLIST(clist));
	do {
		ent = all_records->data;
		if ( ent->shown == TRUE && az[ent->frombook-1] == TRUE ) {
			for ( i=0; i<nb_col;i++ ) {
				newrow[i] = ent->info[itl[i]]->str;
			}
			gtk_clist_append( GTK_CLIST (clist), newrow);
		}
		if ( all_records->next == NULL ) {
			dontstop = FALSE;
		} else {
			all_records = g_list_next(all_records);
		}
	} while ( dontstop );
	g_free(az);
	gtk_clist_thaw(GTK_CLIST(clist));

	return;
}

void sort_column(GtkCList *clist, gint column)
{
	if ( srwc ) { save_record(NULL,0); }

	base_sort(itl[column]);
	fillclist();
	show_record_inform();
}

void select_record(GtkCList *clist, gint row, gint column, \
				GdkEventButton *event, GtkWidget* butform)
{
	shown_record = row;
	show_record_inform();
	if ( ofwos == TRUE && form_window != NULL ) {
		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(butform), TRUE );
	}
}

gboolean close_list (GtkObject *object, gpointer user_data)
{
	GtkWidget *menuitem;
	
	if ( !(startup_mode & 0x01) ) {
		gtk_main_quit();
	} else {
		menuitem = gtk_object_get_data(GTK_OBJECT(list_window), \
				"menuitem" );
		gtk_widget_set_sensitive(menuitem, TRUE);
		gtk_widget_hide (list_window);
	}
	return TRUE;
}

void search_event(GtkWidget *widget, GtkWidget *search_combo)
{
	GString *st;
	st = g_string_new(gtk_entry_get_text(GTK_ENTRY(search_combo)));
	record_select(st, colsearch, 1);
	g_string_free(st, 1);
	fillclist();
	show_record_inform();
}

static void setsearch(GtkWidget *widget, gint a)
{
	colsearch = a;
}

void destroy_list (GtkWidget *widget, gpointer data)
{
	GtkWidget *menuitem;
	list_window = create_list_window();
	menuitem = gtk_object_get_data(GTK_OBJECT(list_window), "menuitem" );
	gtk_widget_set_sensitive(menuitem, TRUE);
}

void form_toggle (GtkWidget *widget, GtkWidget *butclose)
{
	if (GTK_TOGGLE_BUTTON (widget)->active)
	{
		gtk_widget_show(GTK_WIDGET(form_window));
		gtk_widget_set_sensitive(butclose, TRUE);
	} else {
		gtk_widget_hide(GTK_WIDGET(form_window));
		if ( startup_mode & 0x01 ) {
			gtk_widget_set_sensitive(butclose, FALSE);
		}
	}
}

void advsearch_click (GtkWidget *widget, GtkWidget *butadvsearch)
{
	gtk_widget_show(create_advsearch_window());
}

GtkWidget* create_list_window ()
{
	GtkWidget	*win,
			*list_vbox,
			*list_hbuttonbox,
			*searchbox,
			*searchcombo,
			*butclose, *butform, *butadvsearch,
			*hs,
			*option_menu,
			*optionmenu_menu,
			*label;
#if ( ( GTK_MAJOR_VERSION == 1 && \
		GTK_MINOR_VERSION == 1 && GTK_MICRO_VERSION >= 5 ) || \
	( GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 2 ) || \
	( GTK_MAJOR_VERSION > 1 ))
	GtkWidget	*sclwin;
#endif
	gint i;
	
	if ( list_window != NULL ) {
		return list_window;
	}
	
	win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	gtk_container_border_width (GTK_CONTAINER (win), 5);
	gtk_signal_connect (GTK_OBJECT (win), "delete_event", \
			GTK_SIGNAL_FUNC (close_list), NULL);
	gtk_signal_connect (GTK_OBJECT (win), "destroy", \
			GTK_SIGNAL_FUNC (destroy_list), NULL);
			
	gtk_window_set_title (GTK_WINDOW (win), _("Gaby [List]") );
	gtk_window_set_policy (GTK_WINDOW (win), TRUE, TRUE, FALSE);
	gtk_widget_set_usize (GTK_WIDGET(win), 400, 400);
	
	list_vbox = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (list_vbox);
	gtk_container_add (GTK_CONTAINER (win), list_vbox);

	clist = gtk_clist_new (nb_col);
	gtk_widget_show (clist);
#if ( ( GTK_MAJOR_VERSION == 1 && \
		GTK_MINOR_VERSION == 1 && GTK_MICRO_VERSION >= 5 ) || \
	( GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 2 ) || \
	( GTK_MAJOR_VERSION > 1 ))
	sclwin = gtk_scrolled_window_new (NULL, NULL);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sclwin), \
			GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
	gtk_container_add (GTK_CONTAINER (sclwin), clist);
	gtk_box_pack_start (GTK_BOX (list_vbox), sclwin, TRUE, TRUE, 0);
	gtk_widget_show(sclwin);
#else	
	gtk_clist_set_policy (GTK_CLIST (clist), GTK_POLICY_ALWAYS, \
			GTK_POLICY_AUTOMATIC);
	gtk_box_pack_start (GTK_BOX (list_vbox), clist, TRUE, TRUE, 0);
#endif	

	gtk_container_border_width (GTK_CONTAINER (clist), 4);
	for ( i=0; i< nb_col-1; i++ ) {
		gtk_clist_set_column_width (GTK_CLIST(clist),i,360/nb_col);
	}
	gtk_clist_set_column_width (GTK_CLIST (clist), i, 320-i*(360/nb_col) );
	gtk_clist_set_column_justification (GTK_CLIST(clist), nb_col-1, \
			GTK_JUSTIFY_RIGHT );
	gtk_clist_set_row_height(GTK_CLIST (clist), 20);
	gtk_clist_column_titles_show (GTK_CLIST (clist));

	for ( i=0; i<nb_col;i++ ) {
		gtk_clist_set_column_title( GTK_CLIST (clist), i , \
				_(labels[itl[i]]));
	}
	gtk_signal_connect(GTK_OBJECT (clist), "click_column", \
			GTK_SIGNAL_FUNC (sort_column), NULL );
	
	searchbox = gtk_hbox_new(FALSE,0);
	gtk_widget_show(searchbox);
	gtk_box_pack_start(GTK_BOX(list_vbox), searchbox, FALSE, TRUE, 5);

	label = gtk_label_new(_("Search for" ));
	gtk_widget_show(label);
	gtk_box_pack_start (GTK_BOX (searchbox), label, TRUE, FALSE, 5);
	
	searchcombo = gtk_entry_new_with_max_length(50);
	gtk_signal_connect(GTK_OBJECT(searchcombo), "changed", \
			GTK_SIGNAL_FUNC(search_event), searchcombo);
	gtk_widget_show(searchcombo);
	gtk_box_pack_start (GTK_BOX (searchbox), searchcombo, TRUE, FALSE, 5);
	
	label = gtk_label_new(_("in"));
	gtk_widget_show(label);
	gtk_box_pack_start (GTK_BOX (searchbox), label, TRUE, FALSE, 5);

	option_menu = gtk_option_menu_new ();
	gtk_widget_show (option_menu);
	gtk_box_pack_start (GTK_BOX (searchbox), option_menu, TRUE, FALSE, 5);
	optionmenu_menu = create_labels_menu(0, GTK_SIGNAL_FUNC(setsearch));

	gtk_option_menu_set_menu(GTK_OPTION_MENU(option_menu), optionmenu_menu);
	
	hs = gtk_hseparator_new ();
	gtk_widget_show (hs);
	gtk_box_pack_start (GTK_BOX (list_vbox), hs, FALSE, TRUE, 0);
			
	list_hbuttonbox = gtk_hbutton_box_new ();
	gtk_button_box_set_layout (GTK_BUTTON_BOX (list_hbuttonbox), \
			GTK_BUTTONBOX_SPREAD);
	gtk_widget_show (list_hbuttonbox);
	gtk_box_pack_start (GTK_BOX (list_vbox), list_hbuttonbox, \
							FALSE, TRUE, 0);
	gtk_container_border_width (GTK_CONTAINER (list_hbuttonbox), 5);
	
	if ( !(startup_mode & 0x01 )  ) {
		butclose = gtk_button_new_with_label (_("Exit"));
	} else {
		butclose = gtk_button_new_with_label (_("Close"));
	}
	gtk_widget_show (butclose);

	butform = gtk_toggle_button_new_with_label(_("Form window"));
	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(butform), \
			startup_mode & 0x01 );
	gtk_signal_connect (GTK_OBJECT (butform), "toggled", \
			GTK_SIGNAL_FUNC (form_toggle), butclose);
	gtk_widget_show(butform);
	gtk_container_add (GTK_CONTAINER (list_hbuttonbox), butform);
	
	butadvsearch = gtk_button_new_with_label(_("Advanced search"));
	gtk_signal_connect (GTK_OBJECT (butadvsearch), "clicked", \
			GTK_SIGNAL_FUNC (advsearch_click), butadvsearch);
	gtk_widget_set_sensitive(butadvsearch, FALSE);
/*	gtk_widget_show(butadvsearch);*/
	gtk_container_add (GTK_CONTAINER (list_hbuttonbox), butadvsearch);
	
	gtk_signal_connect (GTK_OBJECT (butclose), "clicked", \
			GTK_SIGNAL_FUNC (close_list), NULL);
	
	gtk_signal_connect(GTK_OBJECT(clist), "select_row", \
			GTK_SIGNAL_FUNC(select_record), butform);
	gtk_container_add (GTK_CONTAINER (list_hbuttonbox), butclose);

	fillclist();
	
	return win;
}
